@@ -30,6 +30,7 @@
 
 #include "mgl2/base.h"
 #include "mgl2/mgl.h"
+#include "mgl2/datac.h"
 #include "mgl2/font.h"
 #include "mgl2/eval.h"
 #include "mgl2/evalc.h"
@@ -75,7 +76,53 @@ void mgls_prepare3v(mglData *ex, mglData *ey, mglData *ez);
 void save(mglGraph *gr,const char *name,const char *suf);
 void test(mglGraph *gr)
 {
-	mglParse par;
+	/*ode r 'y;-1' 'xy' [0,1] 0.1 10 'abs(x);y*(1-2*(x<0))':plot r(0):axis:box*/
+	mglData ri(2);	ri[1]=1;
+	mglData rr=mglODE("y;-1","xy",ri, 0.1, 10, "abs(x);y*(1-2*(x<0))");
+	gr->Axis();	gr->Box();	gr->Plot(rr.SubData(0));
+	return;
+	
+	dual res = mgl_atoc("-i6.22018e-06",1);
+	printf("%g, %g\n",real(res), imag(res));
+	return;
+	
+	mglData ray=mglRay("p^2+q^2+i*p*(p>0)",mglPoint(0,-1,0),mglPoint(0,0.5,0),0.01,2);
+	mglData re(128), im(128);
+	gr->Fill(re, "exp(-(200*x/15)^2*0.4^2/2)");
+	mglData bb=mglQO2d("p^2+q^2+i*p*(p>0)", re, im, ray, 0.4, -200);
+	mglData pb = bb.SubData(-1,-1,1).Hist(51,-1,1);
+	pb.Norm(0,1);	gr->Bars(pb,"2r");
+	return;
+	
+	const long nn=10001;
+	mglData j(nn);		j.Fill(0,nn-1);	j.Name("j");
+	mglDataC u(nn), r1(nn), r2, r3(nn);
+	u.Modify("exp(-6*x*x)");	u.Name("u");
+	HCDT var[MGL_VS];	memset(var,0,MGL_VS*sizeof(HCDT));
+	var['j'-'a'] = &j;	var['u'-'a']=&u;
+	const long num = 100;
+	std::vector<mglDataA*> vars;
+	vars.push_back(&j);	vars.push_back(&u);
+	
+	const char *eq = "1i*(u(j-1)+u(j+1)+2*norm(u(j))*u(j))/4";
+	mglExprC ex(eq);
+	time_t st, en1, en2, en3;	time(&st);
+	for(long i=0;i<num;i++)		ex.CalcV(&r1,var);
+	time(&en1);	printf("time is %g sec\n",difftime(en1,st));
+// 	return;
+	for(long i=0;i<num;i++)		r2 = mglData(true, mglFormulaCalc(eq, vars));
+	time(&en2);	printf("time is %g sec\n",difftime(en2,en1));
+	for(long i=0;i<num;i++)	
+	{
+#pragma omp parallel for schedule(static)
+		for(long ii=0;ii<nn;ii++)
+			r3.a[ii] = (u.a[ii-1]+u.a[ii+1]+2.*norm(u.a[ii])*u.a[ii])*dual(0,0.25);
+//			r3.a[ii] = dual(0,1)*(u.a[long(j.a[ii]+0.5)-1]+u.a[long(j.a[ii]+0.5)+1]+2*norm(u.a[long(j.a[ii]+0.5)])*u.a[long(j.a[ii]+0.5)])/4.;
+	}
+	time(&en3);	printf("time is %g sec\n",difftime(en3,en2));
+	return;
+	
+ 	mglParse par;
 	par.Execute(gr,"plot [0,-1,nan,0.1,0.5,1.1] 'o'");	//fplot 'x'");	//"box:fplot '2*sin(pi*x)' 'ko'");
 // 	par.Execute(gr,"colorbar;size -2;crange 0 1;value 90");
 // 	par.Execute(gr,"fplot 'x';legend 'рус':legend");
