@@ -12,5 +12,5 @@ gr.Light(True)		# enable lighting
 gr.Surf(dat)		# plot surface
 gr.Cont(dat,"y")	# plot yellow contour lines
 gr.Axis()			# draw axis
-gr.Puts(mglPoint(1,1,1.2),"\i f = \dfrac{1}{1+(5x-5)^2+(5y-5)^2}")
+gr.Puts(mglPoint(1,1,1.2),"\\i f = \\dfrac{1}{1+(5x-5)^2+(5y-5)^2}")
 gr.WriteFrame("sample.png")	# save it
