@@ -76,7 +76,7 @@ void mglCanvas::SetSize(int w,int h,bool clf)
 	C = new unsigned char[s*12];
 	Z = new float[s*3];	// only 3 planes
 	OI= new int[s];
-#pragma omp parallel for
+#pragma omp parallel for schedule(static)
 	for(long i=0;i<s;i++)
 	{	unsigned char *b=GB+4*i;
 		b[0]=BDef[0];	b[1]=BDef[1];	b[2]=BDef[2];	b[3]=0/*BDef[3]*/;	}
@@ -98,7 +98,7 @@ void mglCanvas::SetSize(int w,int h,bool clf)
 #endif
 		const long m = long(Prm.size());
 		double dd = dx>dy?dy:dx;
-#pragma omp parallel for	// Scale text
+#pragma omp parallel for schedule(static)	// Scale text
 		for(long i=0;i<m;i++)	if(Prm[i].type==4)
 		{
 			mglPnt &q = Pnt[Prm[i].n1];
@@ -121,7 +121,7 @@ void mglCanvas::SetSize(int w,int h,bool clf)
 		{
 			mglStack<mglPnt>  &pnt = DrwDat[k].Pnt;
 			const long n = long(pnt.size());
-#pragma omp parallel for
+#pragma omp parallel for schedule(static)
 			for(long i=0;i<n;i++)
 			{
 				mglPnt &q = pnt[i];
@@ -478,16 +478,16 @@ void mglCanvas::Finish()
 	if(BBoxX1>=0 && BBoxX1<x2 && BBoxY1>=0 && BBoxY1<y2)
 	{
 		unsigned char ff[8]={255,255,255,255, 0,0,0,255}, *g1 = G4+BBoxX1*4-4;
-		int ww = 8*Width;
+		const long w = 4*Width;
 		if(BBoxX1>0)	for(long i=0;i<Height/2-1;i++)
-		{	unsigned char *g=g1+ww*i;
+		{	unsigned char *g=g1+2*w*i, *h=g+w;
 			g[0]=ff[0];	g[1]=ff[1];	g[2]=ff[2];	g[3]=ff[3];
-			g[4]=ff[4];	g[5]=ff[5];	g[6]=ff[6];	g[7]=ff[7];	}
+			h[0]=ff[4];	h[1]=ff[5];	h[2]=ff[6];	h[3]=ff[7];	}
 		g1 = G4+x2*4;
 		if(x2<Width)	for(long i=0;i<Height/2-1;i++)
-		{	unsigned char *g=g1+ww*i;
+		{	unsigned char *g=g1+2*w*i, *h=g+w;
 			g[0]=ff[0];	g[1]=ff[1];	g[2]=ff[2];	g[3]=ff[3];
-			g[4]=ff[4];	g[5]=ff[5];	g[6]=ff[6];	g[7]=ff[7];	}
+			h[0]=ff[4];	h[1]=ff[5];	h[2]=ff[6];	h[3]=ff[7];	}
 		g1 = G4+(BBoxY1-1)*4*Width;
 		if(BBoxY1>0)	for(long i=0;i<Width/2-1;i++)
 		{	unsigned char *g=g1+8*i;
@@ -516,7 +516,7 @@ void mglCanvas::ClfZB(bool force)
 	if(!force && (Quality&MGL_DRAW_LMEM))	return;
 	long n=Width*Height;
 	memset(C,0,12*n);	memset(OI,0,n*sizeof(int));
-#pragma omp parallel for
+#pragma omp parallel for schedule(static)
 	for(long i=0;i<3*n;i++)	Z[i] = -1e20f;
 	clr(MGL_FINISHED);
 }
@@ -549,7 +549,7 @@ void mglCanvas::LoadBackground(const char *fname, double alpha)
 {
 	mgl_read_image(&GB,Width,Height,fname);
 	if(alpha<=1 && alpha>=0)
-#pragma omp parallel for //simd
+#pragma omp parallel for schedule(static) //simd
 		for(long i=0;i<Width*Height;i++)	GB[4*i+3] = (unsigned char)(GB[4*i+3]*alpha);
 }
 //-----------------------------------------------------------------------------
@@ -560,7 +560,7 @@ void mglCanvas::LoadBackground(const char *fname, const char *how, double alpha)
 	mgl_read_image(&g,w,h,fname);
 	if(!g)	return;
 	if(alpha<=1 && alpha>=0)
-#pragma omp parallel for //simd
+#pragma omp parallel for schedule(static) //simd
 		for(long i=0;i<w*h;i++)	g[4*i+3] = (unsigned char)(g[4*i+3]*alpha);
 	int ww=Width, hh=Height, ii=0, jj=0;	// canvas range
 	if(mglchr(how,'a'))	{	ww=inW;	hh=inH;	ii=inX;	jj=Height-inY-inH;	}
@@ -624,7 +624,7 @@ void mglCanvas::FillBackground(const mglColor &cc)
 {
 	BDef[0] = (unsigned char)(255*cc.r);	BDef[1] = (unsigned char)(255*cc.g);
 	BDef[2] = (unsigned char)(255*cc.b);	BDef[3] = (unsigned char)(255*cc.a);
-#pragma omp parallel for //simd
+#pragma omp parallel for schedule(static) //simd
 	for(long i=0;i<Width*Height;i++)
 	{	unsigned char *b=GB+4*i;
 		b[0]=BDef[0];	b[1]=BDef[1];	b[2]=BDef[2];	b[3]=BDef[3];	}
