@@ -153,7 +153,7 @@ void MGL_EXPORT mgl_data_rnd_discrete(HMDT d, HCDT a)
 	mreal *sum = new mreal[n];
 	for(long i=0; i<n; i++)
 	{	sum[i] = amax;	amax += a->v(i);	}
-#pragma omp parallel for
+#pragma omp parallel for schedule(static)
 	for(long j=0;j<m;j++)
 	{
 		mreal r=amax*mgl_rnd();
